# openexr
%define api		3_1
%define major		30
%define libname		%mklibname openexr %{api} %{major}
%define develname	%mklibname openexr -d

# ilmbase
%define ilm_major	30
%define libname_ilm	%mklibname ilmbase %{api} %{ilm_major}

%bcond_without docs

Name:		openexr
Summary:	A high dynamic-range (HDR) image file format
Version:	3.1.13
Release:	%mkrel 2
Group:		Graphics/Utilities
License:	BSD
URL:		https://www.openexr.com
Source0:	https://github.com/AcademySoftwareFoundation/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:		gcc14.patch
BuildRequires:	cmake
BuildRequires:	pkgconfig(Imath)
BuildRequires:	pkgconfig(zlib)
%if %{with docs}
BuildRequires:	python3-sphinx
BuildRequires:	python3-breathe
BuildRequires:	doxygen
%endif

Provides:	OpenEXR = %{version}-%{release}

%description
Industrial Light & Magic developed the OpenEXR format in response to the demand
for higher color fidelity in the visual effects industry.

### openexr

%package -n	%{libname}
Summary:	Dynamic libraries from %{name}
Group:		System/Libraries

%description -n	%{libname}
Dynamic libraries from %{name}.

%package -n	%{develname}
Summary:	Header files and development libraries from %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_ilm} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	libilmbase-devel = %{version}-%{release}
Provides:	ilmbase-devel = %{version}-%{release}
Provides:	OpenEXR-devel = %{version}-%{release}
Obsoletes:	%{_lib}ilmbase-devel < 3.1.3

%description -n	%{develname}
Libraries and includes files for developing programs based on %{name}.

### ilmbase

%package -n	%{libname_ilm}
Summary:	Dynamic libraries from IlmBase
Group:		System/Libraries

%description -n	%{libname_ilm}
Dynamic libraries from IlmBase.

%prep
%autosetup -p1

%build
%cmake \
  -DDOCS:BOOL=%{?with_docs:ON}%{!?with_docs:OFF} \
  -DINSTALL_DOCS:BOOL=ON
%cmake_build

%install
%cmake_install

%if %{with docs}
# Fixup documentation so it can get installed correctly in imath-devel
rm -rf %{buildroot}%{_datadir}/doc/OpenEXR/sphinx/.{doctrees,buildinfo}
%endif

%files
%doc *.md CODEOWNERS
%{_bindir}/exr*

%files -n %{libname}
%{_libdir}/libOpenEXR-%{api}.so.%{major}{,.*}
%{_libdir}/libOpenEXRCore-%{api}.so.%{major}{,.*}
%{_libdir}/libOpenEXRUtil-%{api}.so.%{major}{,.*}

%files -n %{develname}
%docdir %{_datadir}/doc/OpenEXR/
%doc %{_datadir}/doc/OpenEXR/
%{_includedir}/OpenEXR/
%{_libdir}/libOpenEXR.so
%{_libdir}/libOpenEXR-%{api}.so
%{_libdir}/libOpenEXRCore.so
%{_libdir}/libOpenEXRCore-%{api}.so
%{_libdir}/libOpenEXRUtil.so
%{_libdir}/libOpenEXRUtil-%{api}.so
%{_libdir}/libIex.so
%{_libdir}/libIex-%{api}.so
%{_libdir}/libIlmThread.so
%{_libdir}/libIlmThread-%{api}.so
%{_libdir}/pkgconfig/OpenEXR.pc
%{_libdir}/cmake/OpenEXR/

%files -n %{libname_ilm}
%{_libdir}/libIex-%{api}.so.%{ilm_major}{,.*}
%{_libdir}/libIlmThread-%{api}.so.%{ilm_major}{,.*}


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.1.13-2.mga10
+ Revision: 2225130
- Mageia 10 Mass Rebuild

* Sat Jul 20 2024 daviddavid <daviddavid> 3.1.13-1.mga10
+ Revision: 2082165
- new version: 3.1.13

* Sat Oct 28 2023 daviddavid <daviddavid> 3.1.11-1.mga10
+ Revision: 2002218
- new version: 3.1.11

* Fri May 19 2023 luigiwalser <luigiwalser> 3.1.7-1.mga9
+ Revision: 1957381
- 3.1.7

* Tue Mar 28 2023 luigiwalser <luigiwalser> 3.1.6-1.mga9
+ Revision: 1950541
- 3.1.6

* Fri Apr 22 2022 luigiwalser <luigiwalser> 3.1.5-1.mga9
+ Revision: 1852658
- 3.1.5
- remove patches (fixed upstream)

* Wed Mar 30 2022 umeabot <umeabot> 3.1.3-3.mga9
+ Revision: 1833758
- Mageia 9 Mass Rebuild

* Fri Jan 14 2022 ns80 <ns80> 3.1.3-2.mga9
+ Revision: 1768279
- add upstream patch for CVE-2021-45942 (mga#29888)

* Sat Dec 25 2021 wally <wally> 3.1.3-1.mga9
+ Revision: 1763668
- new version 3.1.3
- rename lib pkgs
- drop ilmbase devel pkg

* Sat Nov 20 2021 ns80 <ns80> 2.5.7-3.mga9
+ Revision: 1758025
- backport upstream patch for CVE-2021-3941 (mga#29657)

* Mon Nov 15 2021 ns80 <ns80> 2.5.7-2.mga9
+ Revision: 1756663
- backport upstream patch for CVE-2021-3933 (mga#29657)

* Mon Jun 28 2021 luigiwalser <luigiwalser> 2.5.7-1.mga9
+ Revision: 1734056
- 2.5.7
- add patches from ubuntu to fix CVE-2021-3478

* Sat Mar 27 2021 daviddavid <daviddavid> 2.5.5-1.mga9
+ Revision: 1711063
- new version: 2.5.5
- new Source Url

* Mon Nov 30 2020 luigiwalser <luigiwalser> 2.5.3-8.mga8
+ Revision: 1650733
- rebuild for jsoncpp

* Wed Nov 18 2020 luigiwalser <luigiwalser> 2.5.3-7.mga8
+ Revision: 1647365
- remove temporary obsoletes

* Wed Nov 18 2020 luigiwalser <luigiwalser> 2.5.3-6.mga8
+ Revision: 1647358
- temporarily obsolete old ilmbase library

* Sat Sep 12 2020 daviddavid <daviddavid> 2.5.3-5.mga8
+ Revision: 1625181
- add conflicts to ease upgrade

* Sat Sep 12 2020 daviddavid <daviddavid> 2.5.3-4.mga8
+ Revision: 1625167
- split out in their own sub-pkgs the ilmbase stack
- make sure old ilmbase-devel pkg is removed

* Tue Sep 08 2020 akien <akien> 2.5.3-3.mga8
+ Revision: 1623576
- Don't obsolete lib package, it can stay installed in parallel

* Tue Sep 08 2020 akien <akien> 2.5.3-2.mga8
+ Revision: 1623541
- Fix invalid Obsoletes for ilmbase

* Sun Sep 06 2020 guillomovitch <guillomovitch> 2.5.3-1.mga8
+ Revision: 1622886
- new version 2.5.3

* Thu Aug 20 2020 joequant <joequant> 2.3.0-6.mga8
+ Revision: 1616876
- bump
- revert arm64 workaround

* Wed Apr 29 2020 ns80 <ns80> 2.3.0-5.mga8
+ Revision: 1573198
- add patches from Ubuntu for CVE-2020-1175[89] and CVE-2020-1176[0-5] (mga#26551)

* Tue Feb 18 2020 umeabot <umeabot> 2.3.0-4.mga8
+ Revision: 1538800
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 27 2019 daviddavid <daviddavid> 2.3.0-3.mga8
+ Revision: 1463064
- add opensuse patch to fix CVE-2017-14988 (mga#25758)

* Wed May 08 2019 mrambo3501 <mrambo3501> 2.3.0-2.mga7
+ Revision: 1396760
- add upstream patch which fixes CVE-2018-18444 (mga#24759)

* Mon Oct 15 2018 zezinho <zezinho> 2.3.0-1.mga7
+ Revision: 1320440
- new version 2.3.0
+ daviddavid <daviddavid>
- rebuild for new ilmbase 2.3.0

* Sun Sep 23 2018 umeabot <umeabot> 2.2.1-2.mga7
+ Revision: 1300013
- Mageia 7 Mass Rebuild

* Sun May 27 2018 wally <wally> 2.2.1-1.mga7
+ Revision: 1232387
- new version 2.2.1
- new lib major 23
- drop upstreamed patches

* Tue Jan 09 2018 neoclust <neoclust> 2.2.0-11.mga7
+ Revision: 1191900
- Rebuild against new IlmBase

* Sat Jul 01 2017 akien <akien> 2.2.0-10.mga6
+ Revision: 1108837
- Backport upstream PR to fix CVE-2017-911[026] (mga#20912)

* Wed Dec 28 2016 wally <wally> 2.2.0-9.mga6
+ Revision: 1078508
- obsolete old OpenEXR pkg

* Wed Dec 28 2016 wally <wally> 2.2.0-8.mga6
+ Revision: 1078475
- add provides for OpenEXR-devel

* Wed Dec 28 2016 wally <wally> 2.2.0-7.mga6
+ Revision: 1078452
- use lower case source pkg name
- fix lib pkg name (but keep old lower cased devel pkg name)

* Fri Feb 12 2016 umeabot <umeabot> 2.2.0-6.mga6
+ Revision: 956545
- Mageia 6 Mass Rebuild

* Tue Aug 25 2015 cjw <cjw> 2.2.0-5.mga6
+ Revision: 869264
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 2.2.0-4.mga5
+ Revision: 739717
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.0-3.mga5
+ Revision: 686714
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 2.2.0-2.mga5
+ Revision: 677645
- Mageia 5 Mass Rebuild

* Sat Aug 23 2014 luigiwalser <luigiwalser> 2.2.0-1.mga5
+ Revision: 666901
- 2.2.0
- library major is now 22

* Fri Apr 25 2014 shlomif <shlomif> 2.1.0-1.mga5
+ Revision: 617985
- New version 2.1.0

* Sat Oct 19 2013 umeabot <umeabot> 2.0.1-2.mga4
+ Revision: 534405
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 fwang <fwang> 2.0.1-1.mga4
+ Revision: 477838
- br zlib
- try build normally
- fltk is not required
- disable test prog
- new version 2.0.1

* Fri Jan 11 2013 umeabot <umeabot> 1.7.1-2.mga3
+ Revision: 345071
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Sun Dec 02 2012 fwang <fwang> 1.7.1-1.mga3
+ Revision: 324982
- new version 1.7.1

* Fri Jan 14 2011 mikala <mikala> 1.7.0-1.mga2
+ Revision: 18057
- Drop mdk macros
- Remove BuildRoot
- imported package OpenEXR

